@@ -626,7 +626,7 @@ ghex_window_load(GHexWindow *win, const gchar *filename)
 }
 
 static gchar* 
-escape_underscores (const gchar* text)
+encode_xml_and_escape_underscores(gchar *text)
 {
 	GString *str;
 	gint length;
@@ -650,6 +650,69 @@ escape_underscores (const gchar* text)
         case '_':
             g_string_append (str, "__");
             break;
+        case '&':
+            g_string_append (str, "&amp;");
+            break;
+        case '<':
+            g_string_append (str, "&lt;");
+            break;
+        case '>':
+            g_string_append (str, "&gt;");
+            break;
+        case '"':
+            g_string_append (str, "&quot;");
+            break;
+        case '\'':
+            g_string_append (str, "&apos;");
+            break;
+        default:
+            g_string_append_len (str, p, next - p);
+            break;
+        }
+        
+        p = next;
+    }
+    
+	return g_string_free (str, FALSE);
+}
+
+static gchar* 
+encode_xml (const gchar* text)
+{
+	GString *str;
+	gint length;
+	const gchar *p;
+ 	const gchar *end;
+
+  	g_return_val_if_fail (text != NULL, NULL);
+
+    length = strlen (text);
+
+	str = g_string_new ("");
+
+  	p = text;
+  	end = text + length;
+
+  	while (p != end) {
+        const gchar *next;
+        next = g_utf8_next_char (p);
+
+		switch (*p) {
+        case '&':
+            g_string_append (str, "&amp;");
+            break;
+        case '<':
+            g_string_append (str, "&lt;");
+            break;
+        case '>':
+            g_string_append (str, "&gt;");
+            break;
+        case '"':
+            g_string_append (str, "&quot;");
+            break;
+        case '\'':
+            g_string_append (str, "&apos;");
+            break;
         default:
             g_string_append_len (str, p, next - p);
             break;
@@ -682,15 +745,17 @@ ghex_window_add_doc_to_list(GHexWindow *win, HexDocument *doc)
 {
     gchar *menu = NULL, *verb_name;
     gchar *cmd = NULL;
-    gchar *escaped_name;
+    gchar *escaped_name, *encoded_name;
     gchar *tip;
 
-    escaped_name = escape_underscores(doc->path_end);
-    tip = g_strdup_printf(_("Activate file %s"), doc->path_end);
+    escaped_name = encode_xml (doc->path_end);
+    tip = g_strdup_printf(_("Activate file %s"), escaped_name);
+    g_free(escaped_name);
+    escaped_name = encode_xml_and_escape_underscores(doc->path_end);
     verb_name = g_strdup_printf("FilesFile_%p", doc);
     menu = g_strdup_printf("<menuitem name=\"%s\" verb=\"%s\" label=\"%s\"/>",
                            verb_name, verb_name, escaped_name);
-    cmd = g_strdup_printf("<cmd name=\"%s\" _label=\"%s\" _tip=\"%s\"/>",
+    cmd = g_strdup_printf("<cmd name=\"%s\" label=\"%s\" _tip=\"%s\"/>",
                           verb_name, escaped_name, tip);
     g_free(tip);
     g_free(escaped_name);
@@ -725,8 +790,12 @@ ghex_window_get_ui_component(GHexWindow *win)
 void
 ghex_window_set_doc_name(GHexWindow *win, const gchar *name)
 {
-    gchar *title = g_strdup_printf(_("GHex - %s"), name);
-    gtk_window_set_title(GTK_WINDOW(win), title);
+    if(name != NULL) {
+        gchar *title = g_strdup_printf(_("GHex - %s"), name);
+        gtk_window_set_title(GTK_WINDOW(win), title);
+        g_free(title);
+    }
+    else gtk_window_set_title(GTK_WINDOW(win), _("GHex"));
 }
 
 struct _MessageInfo {
@@ -877,12 +946,17 @@ ghex_window_save_as(GHexWindow *win)
 		gchar *flash;
 		int i;
         gint save = 0;
+        gchar *gtk_file_name, *path_end;
 
         if(access(filename, F_OK) == 0) {
             GnomeMessageBox *mbox;
-            gchar *msg = g_strdup_printf(_("File %s exists.\n"
-                                           "Do you want to overwrite it?"),
-                                         filename);
+            gchar *msg;
+
+            gtk_file_name = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
+            msg= g_strdup_printf(_("File %s exists.\n"
+                                   "Do you want to overwrite it?"),
+                                 gtk_file_name);
+            g_free(gtk_file_name);
             mbox = GNOME_MESSAGE_BOX(gnome_message_box_new(msg,
                                                            GNOME_MESSAGE_BOX_QUESTION,
                                                            GNOME_STOCK_BUTTON_YES,
@@ -897,6 +971,8 @@ ghex_window_save_as(GHexWindow *win)
                 if(hex_document_write_to_file(doc, file)) {
                     if(doc->file_name)
                         g_free(doc->file_name);
+                    if(doc->path_end)
+                        g_free(doc->path_end);
                     doc->file_name = strdup(filename);
                     doc->changed = FALSE;
                     win->changed = FALSE;
@@ -906,14 +982,15 @@ ghex_window_save_as(GHexWindow *win)
                         i--)
                         ;
                     if(doc->file_name[i] == '/')
-                        doc->path_end = &doc->file_name[i+1];
+                        path_end = &doc->file_name[i+1];
                     else
-                        doc->path_end = doc->file_name;
-                    
+                        path_end = doc->file_name;
+                    doc->path_end = g_filename_to_utf8(path_end, -1, NULL, NULL, NULL);
                     ghex_window_set_doc_name(win, doc->path_end);
-                    
-                    flash = g_strdup_printf(_("Saved buffer to file %s"), doc->file_name);
+                    gtk_file_name = g_filename_to_utf8(doc->file_name, -1, NULL, NULL, NULL);
+                    flash = g_strdup_printf(_("Saved buffer to file %s"), gtk_file_name);
                     ghex_window_flash(win, flash);
+                    g_free(gtk_file_name);
                     g_free(flash);
                 }
                 else {
